/*
 * Copyright (C) 2012-2013 Japan Smartphone Security Association
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jssec.android.clipboard;

import android.app.Activity;
import android.content.ComponentName;
import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.NavUtils;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Toast;

public class ClipboardListeningActivity extends Activity {
    private static final String TAG = "ClipboardListeningActivity";
    private boolean isServiceRunning;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_clipboard_listening);

        isServiceRunning = ServiceRunningStatus.getStatus(getApplicationContext());
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.activity_clipboard_listening, menu);
        return true;
    }

    public void onClickStartService(View view) {
        if (view.getId() != R.id.start_service_button) {
            Log.w(TAG, "View ID is incorrect.");
        } else {
            if (!isServiceRunning) {
                ComponentName cn = startService(
                        new Intent(ClipboardListeningActivity.this, ClipboardListeningService.class));
                if (cn != null) {
                    this.isServiceRunning = true;
                } else {
                    Log.e(TAG, "Failed to launch the service.");
                    Toast.makeText(this, "Failed to launch the service.", Toast.LENGTH_SHORT).show();
                }
            } else {
                Toast.makeText(this, "Service has been already launched.", Toast.LENGTH_SHORT).show();

            }
        }
    }

    public void onClickStopService(View view) {
        if (view.getId() != R.id.stop_service_button) {
            Log.w(TAG, "View ID is incorrect.");
        } else {
            if (isServiceRunning) {
                boolean res = stopService(
                        new Intent(ClipboardListeningActivity.this, ClipboardListeningService.class));
                if (res) {
                    this.isServiceRunning = false;
                } else {
                    Log.e(TAG, "Failed to stop the service.");
                    Toast.makeText(this, "Failed to stop the service.", Toast.LENGTH_SHORT).show();
                }
            } else {
                Toast.makeText(this, "Service has been already stopped.", Toast.LENGTH_SHORT).show();

            }
        }
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case android.R.id.home:
                NavUtils.navigateUpFromSameTask(this);
                return true;
        }
        return super.onOptionsItemSelected(item);
    }

}
