/*
 * Copyright (C) 2012-2013 Japan Smartphone Security Association
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jssec.android.clipboard;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;

import android.content.Context;
import android.util.Log;

public class ServiceRunningStatus {
    private static final String STATE_STORE_FILE = "service_running_status";
    private static final String TAG = "ServiceRunningStatus";
    private static Context sContext;
    private static Boolean status;

    private static FileOutputStream openFileForUpdate() throws FileNotFoundException {
        return sContext.openFileOutput(STATE_STORE_FILE, Context.MODE_PRIVATE);
    }

    private static FileInputStream openFileForRead() throws IOException {
        try {
            return sContext.openFileInput(STATE_STORE_FILE);
        } catch (FileNotFoundException e) {
            try {
                FileOutputStream fos = openFileForUpdate();
                writeString(fos, String.valueOf(false));
                fos.close();
                return openFileForRead();
            } catch (FileNotFoundException fe) {
                throw fe;
            } catch (IOException ioe) {
                throw ioe;
            }
        }
    }

    private static String readString(FileInputStream fis) throws IOException {
        BufferedReader br = null;
        try {
            br = new BufferedReader(new InputStreamReader(fis));
            return br.readLine();
        } finally {
            if (br != null) {
                br.close();
            }
        }
    }

    private static void writeString(FileOutputStream fos, String str) throws IOException {
        PrintWriter pw = null;
        try {
            pw = new PrintWriter(fos);
            pw.write(str);
        } finally {
            if (pw != null) {
                pw.close();
            }
        }
    }

    protected static boolean getStatus(Context context) {
        if (ServiceRunningStatus.status != null) {
            return ServiceRunningStatus.status;
        }
        if (context == null) {
            Log.e(TAG, "context is null");
            return false;
        }
        sContext = context;
        FileInputStream fis = null;
        try {
            fis = openFileForRead();
            boolean ret = Boolean.valueOf(readString(fis));
            return ret;
        } catch (IOException e) {
            return false;
        } finally {
            if (fis != null) {
                try {fis.close();} catch (Exception e) {}
            }
        }
    }

    protected static void setStatus(Context context, boolean status) {
        if (context == null) {
            Log.e(TAG, "context is null");
            return;
        }
        sContext = context;
        FileOutputStream fos = null;
        try {
            fos = openFileForUpdate();
            writeString(fos, String.valueOf(status));
            ServiceRunningStatus.status = status;
        } catch (IOException e) {
            return;
        } finally {
            if (fos != null) {
                try {fos.close();} catch (Exception e) {}
            }
        }
    }
}
